# shows
lib for system monitoring with CPU/GPU/DISK/MEM/NET

## install
`pip install shows`

## usage
### bash
after installation, type the following in your terminal:
```bash
shows
```

### python
```python
import shows
machine  = shows.machine()
machine.get_state()
```
